import logging
from sqlalchemy.orm import Session

from app.core.config import settings
from app.crud.crud_user import create_user, get_user_by_email
from app.schemas.user import UserCreate, UserRole
from app.db.base import Base
from app.db.session import engine


logger = logging.getLogger(__name__)


def init_db(db: Session) -> None:
    # Create tables if they don't exist
    Base.metadata.create_all(bind=engine)
    
    # Create initial admin user if it doesn't exist
    admin_user = get_user_by_email(db, email=settings.ADMIN_EMAIL)
    if not admin_user:
        user_in = UserCreate(
            email=settings.ADMIN_EMAIL,
            password=settings.ADMIN_PASSWORD,
            is_active=True,
            role=UserRole.ADMIN,
            full_name="Admin User"
        )
        create_user(db, obj_in=user_in)
        logger.info(f"Admin user {settings.ADMIN_EMAIL} created")
    else:
        logger.info(f"Admin user {settings.ADMIN_EMAIL} already exists")