from sqlalchemy import Column, Integer, String, Float, ForeignKey, Text
from sqlalchemy.orm import relationship
import enum

from app.db.base_class import Base


class DepositStatus(str, enum.Enum):
    PENDING = "pending"
    APPROVED = "approved"
    REJECTED = "rejected"


class Deposit(Base):
    id = Column(Integer, primary_key=True, index=True)
    user_id = Column(Integer, ForeignKey("user.id"), nullable=False)
    amount = Column(Float, nullable=False)
    transaction_hash = Column(String, nullable=False)
    proof_image_path = Column(String, nullable=True)
    status = Column(String, default=DepositStatus.PENDING, nullable=False)
    admin_notes = Column(Text, nullable=True)
    
    # Relationships
    user = relationship("User", back_populates="deposits")
    transaction = relationship("Transaction", back_populates="deposit", uselist=False, cascade="all, delete-orphan")