from sqlalchemy import Column, Integer, String, Float, ForeignKey, Text
from sqlalchemy.orm import relationship
import enum

from app.db.base_class import Base


class WithdrawalStatus(str, enum.Enum):
    PENDING = "pending"
    APPROVED = "approved"
    REJECTED = "rejected"


class Withdrawal(Base):
    id = Column(Integer, primary_key=True, index=True)
    user_id = Column(Integer, ForeignKey("user.id"), nullable=False)
    amount = Column(Float, nullable=False)
    fee = Column(Float, nullable=False, default=0.0)
    wallet_address = Column(String, nullable=False)
    status = Column(String, default=WithdrawalStatus.PENDING, nullable=False)
    admin_notes = Column(Text, nullable=True)
    transaction_hash = Column(String, nullable=True)  # For when admin processes withdrawal
    
    # Relationships
    user = relationship("User", back_populates="withdrawals")
    transaction = relationship("Transaction", back_populates="withdrawal", uselist=False, cascade="all, delete-orphan")